@@ -21,7 +21,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c,v 1.41 2002/06/20 06:25:34 beerli Exp $
+$Id: data.c,v 1.42 2002/07/18 14:29:44 beerli Exp $
  
 -------------------------------------------------------*/
 #include <string.h>
@@ -329,7 +329,7 @@ read_header (FILE * infile, data_fmt * data, option_fmt * options)
                 &(data->loci), options->title);
         break;
     case 'g':   /* fall through if a menu change forces to analyze data
-                           instead of using the already sampled genealogies */
+                               instead of using the already sampled genealogies */
         if (options->datatype == 'g')
             break;
         else
@@ -439,22 +439,26 @@ read_popheader (FILE * infile, data_fmt * data, long pop, long genomes)
         for(locus=1; locus< data->loci; locus++)
         {
             tmp = strtok(NULL," ");
-            if(isdigit(tmp[0]))
+            if(tmp!=NULL)
             {
-                data->numind[pop][locus] = atol(tmp);
-                data->numalleles[pop][locus] = data->numind[pop][locus]*genomes;
-            }
-            else
-            {
-                havepopname=TRUE;
-                strncpy(data->popnames[pop],tmp,MIN(strlen(tmp),80));
-                break;
+                if(isdigit(tmp[0]))
+                {
+                    data->numind[pop][locus] = atol(tmp);
+                    data->numalleles[pop][locus] = data->numind[pop][locus]*genomes;
+                }
+                else
+                {
+                    havepopname=TRUE;
+                    strncpy(data->popnames[pop],tmp,MIN(strlen(tmp),80));
+                    break;
+                }
             }
         }
         if(!havepopname)
         {
             tmp = strtok(NULL," ");
-            strncpy(data->popnames[pop],tmp,MIN(strlen(tmp),80));
+            if(tmp!=NULL)
+                strncpy(data->popnames[pop],tmp,MIN(strlen(tmp),80));
         }
         // fills numind for additional locus in case the numind was not specified
         for(lo=locus; lo< data->loci; lo++)
@@ -501,6 +505,8 @@ read_indname (FILE * file, data_fmt * data, long pop, long ind, long nmlength)
         ch = getc (file);
         if(!strchr("\r\n",ch))
             data->indnames[pop][ind][i++] = ch;
+        if(strchr("\t",ch))
+            break;
     }
     data->indnames[pop][ind][nmlength] = '\0';
 }
@@ -565,7 +571,7 @@ read_microalleles (FILE * infile, data_fmt * data, long pop, long ind)
         if (input[0] == '\0')
             FGETS (input, LONGLINESIZE, infile);
         i = 0;
-        while (input[i] != ' ' && input[i] != dlm[0])
+        while (strchr(" \t",input[i]) && input[i] != dlm[0])
         {
             a1[i] = input[i];
             i++;
@@ -576,7 +582,7 @@ read_microalleles (FILE * infile, data_fmt * data, long pop, long ind)
         if (input[i] == dlm[0])
         {
             input++;
-            while (input[i] != ' ' && input[i] != '\0')
+            while (strchr(" \t",input[i]) && input[i] != '\0')
             {
                 a2[i] = input[i];
                 i++;
