@@ -21,7 +21,7 @@ and of course the documentation at:
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: main.c,v 1.81 2002/06/20 06:25:35 beerli Exp $
+$Id: main.c,v 1.83 2002/07/12 18:14:08 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "definitions.h"
@@ -307,6 +307,12 @@ main(int argc, char **argv)
     if (myID == MASTER)
     {
 #endif
+		
+#ifdef BAYESUPDATE
+		if(options->bayes_infer)
+				bayes_stat(EARTH);
+		else
+#endif			
         print_list(universe, options, data);
         if (EARTH->options->gamma)
             print_alpha_curve(EARTH, EARTH->atl, &Gmax);
@@ -368,6 +374,9 @@ main(int argc, char **argv)
     //    master_gridder(world, &Gmax);
 #endif
 
+#ifdef BAYESUPDATE
+	if(!options->bayes_infer)
+#endif
     profile_tables(options, EARTH, &Gmax);
 #else
 #ifdef MPI   /* WORKS */
@@ -379,7 +388,10 @@ main(int argc, char **argv)
         //       master_gridder(EARTH, &Gmax);
 #endif
 
-        profile_tables(options, EARTH, &Gmax);
+#ifdef BAYESUPDATE
+		if(!options->bayes_infer)
+#endif
+			profile_tables(options, EARTH, &Gmax);
 #ifdef MPI
 
     }
@@ -808,12 +820,12 @@ run_locus(world_fmt ** universe, int usize, option_fmt * options,
                 //single chain, single replicate
                 kind = SINGLELOCUS;
                 *Gmax = (EARTH->G > *Gmax) ? EARTH->G + 1 : (*Gmax);
-#ifdef BAYESUPDATE
-
-                if (options->bayes_infer)
-                    bayes_stat(EARTH, EARTH->numpop2);
-                else
-#endif
+//#ifdef BAYESUPDATE
+//
+//                if (options->bayes_infer)
+//                    bayes_stat(EARTH);
+//                else
+//#endif
 
                     estimateParameter(rep, *Gmax, EARTH, options,
                                       EARTH->cov[locus], chain, type, kind,
@@ -850,7 +862,7 @@ run_locus(world_fmt ** universe, int usize, option_fmt * options,
 
         if (options->bayes_infer)
         {
-            bayes_stat(EARTH, EARTH->numpop2);
+           // bayes_stat(EARTH);
             return;
         }
 #endif
@@ -1100,12 +1112,13 @@ analyze_olddata(world_fmt * world,
 #endif
 
     long            Gmax = 0;
+	options->heating = FALSE;
     if (myID == MASTER)
     {
         unset_penalizer_function(TRUE);
         Gmax = read_savesum(world, options, data);
 #ifdef MPI
-
+		
         MPI_Bcast(data->geo, world->numpop2, MPI_DOUBLE, MASTER, comm_world);
         MPI_Bcast(data->lgeo, world->numpop2, MPI_DOUBLE, MASTER, comm_world);
     }
