@@ -15,7 +15,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: menu.c,v 1.54 2002/06/20 06:25:36 beerli Exp $
+$Id: menu.c,v 1.57 2002/07/18 14:29:45 beerli Exp $
  
 -------------------------------------------------------*/
 #include "migration.h"
@@ -1545,7 +1545,19 @@ menuStrategy (option_fmt * options)
         {
         case 0:  //strategy change
             if(!strchr("Yy",input[0]))
+			  {
                 options->bayes_infer = !options->bayes_infer;
+					if(options->bayes_infer)
+					{
+						do
+						  {
+							  printf("BAYESIAN INFERENCE: What is the frequency of the parameter updates vs the tree updates?\n[suggestion: 0.1, actual value: %f]\n", 1./options->updateratio);
+							FGETS (input, LINESIZE, stdin);
+							options->updateratio = 1./(atof (input));
+						  } while(options->updateratio < 1);
+					}
+					input[0]='\0';
+			  }
             break;
         case 1:
             do
@@ -1690,11 +1702,11 @@ menuStrategy (option_fmt * options)
                     ("  of the originally proposed number of samples be?\n");
                     FGETS (input, LINESIZE, stdin);
                     options->acceptfreq = atof (input);
-                    if (options->acceptfreq < 0)
+                    if (options->acceptfreq < 0 || options->acceptfreq > 1)
                         printf ("  Range should be between 0 - 1, and not %f\n",
                                 options->acceptfreq);
                 }
-                while (options->acceptfreq < 0);
+                while (options->acceptfreq < 0 || options->acceptfreq > 1);
             }
             break;
         case 11:
@@ -1781,7 +1793,7 @@ display_standard_mcmc (option_fmt * options)
             options->burn_in);
     if (!options->replicate)
         printf
-        ("  8       Combine chains for estimates?                     No\n");
+        ("  8       Combine chains or runs for estimates?             No\n");
     else
     {
         if (options->replicatenum == 0)
