@@ -10,7 +10,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: migrate_mpi.c,v 1.17 2002/06/20 15:49:19 beerli Exp $
+$Id: migrate_mpi.c,v 1.18 2002/07/18 14:29:45 beerli Exp $
 */
 #ifdef MPI
 #include "migrate_mpi.h"
@@ -440,7 +440,7 @@ mpi_maximize_worker (world_fmt * world, long rep)
 void
 broadcast_options_master (option_fmt * options)
 {
-    int bufsize = MAXBUFSIZE;
+    long bufsize = MAXBUFSIZE;
     char *buffer;
     buffer = (char *) calloc (1, sizeof (char));
     bufsize = save_options_buffer (&buffer, options);
@@ -912,7 +912,7 @@ unpack_mighist_buffer (char *buffer, world_fmt * world,
             aa->mighist[j].migeventsize=0;
             aa->mighist[j].migevents =
                 (migevent_fmt *) calloc (1,  sizeof (migevent_fmt) );
-            printf("%i> first events: alloc=%li size=%li\n", myID, aa->mighist[j].allocsize , aa->mighist[j].migeventsize);
+            //printf("%i> first events: alloc=%li size=%li\n", myID, aa->mighist[j].allocsize , aa->mighist[j].migeventsize);
         }
         aa->allocsize = aa->mighistnum+1;
     }
@@ -921,7 +921,7 @@ unpack_mighist_buffer (char *buffer, world_fmt * world,
         sgets (input, LINESIZE, &buf);
         sscanf (input, "%li %li %li", &aa->mighist[j].copies,
                 &aa->mighist[j].weight, &aa->mighist[j].migeventsize);
-        printf("%i> events: alloc=%li size=%li\n", myID, aa->mighist[j].allocsize , aa->mighist[j].migeventsize);
+        //printf("%i> events: alloc=%li size=%li\n", myID, aa->mighist[j].allocsize , aa->mighist[j].migeventsize);
         aa->mighist[j].allocsize = aa->mighist[j].migeventsize;
         aa->mighist[j].migevents = (migevent_fmt *) realloc (aa->mighist[j].migevents,
                                    sizeof (migevent_fmt) *
@@ -1113,7 +1113,7 @@ mpi_results_master (double sendtype, world_fmt * world, long maxreplicate,
     long offset;
     long i;
     workload = (long*) calloc(world->loci*2+2,sizeof(long));
-    printf("%i> mpi_result_master()\n",myID);
+    //printf("%i> mpi_result_master()\n",myID);
 #endif
 
     temp = (double *) calloc (numelem2, sizeof (double));
@@ -1146,7 +1146,7 @@ mpi_results_master (double sendtype, world_fmt * world, long maxreplicate,
         {
             locus = (int) workload[2*i];
             offset = workload[2*i+1];
-            printf("%i> locus=%i offset=%li\n",myID,locus,offset);
+            //printf("%i> locus=%i offset=%li\n",myID,locus,offset);
             (*unpack) (buffer+offset, world, locus, maxreplicate, numpop);
         }
         z += workerloci-1; //the test condition will add another one
@@ -1190,7 +1190,7 @@ mpi_results_worker (long bufs, world_fmt * world, long maxrep,
     //buf = &buffer;
 #ifdef BIGMEMORY
 
-    printf("%i> mpi_result_worker()\n",myID);
+    //printf("%i> mpi_result_worker()\n",myID);
     fflush(stdout);
     bufsize = 0;
     workload = (long *) calloc(2+world->loci*2, sizeof(long));//{locus1,strlen1,locus2,strlen2,.....,totalstrlen,n_loci}
@@ -1203,7 +1203,7 @@ mpi_results_worker (long bufs, world_fmt * world, long maxrep,
         workload[zz++] = (long) locus;
         workload[zz++] = allbufsize;
         allbufsize += bufsize;
-        printf("%i> locus=%li size=%li\n",myID,workload[zz-2],workload[zz-1]);
+        //printf("%i> locus=%li size=%li\n",myID,workload[zz-2],workload[zz-1]);
         allbuffer = (char *) realloc (allbuffer, sizeof (char)*allbufsize+1);
         strcat(allbuffer,buffer);
         free(buffer);
@@ -1264,6 +1264,7 @@ mpi_broadcast_results (world_fmt * world, long loci,
 #endif
 
     get_time (nowstr, "%H:%M:%S");
+	if(world->options->progress)
     printf("%i> Redistributing the data\nResult parts [Time is %s]\n",myID, nowstr);
 #ifdef BIGMEMORY
 
@@ -1278,7 +1279,7 @@ mpi_broadcast_results (world_fmt * world, long loci,
             workload[zz++] = (long) locus;
             workload[zz++] = allbufsize;
             allbufsize += bufsize;
-            printf("%i> result locus=%li size=%li\n",myID,workload[zz-2],workload[zz-1]);
+            //printf("%i> result locus=%li size=%li\n",myID,workload[zz-2],workload[zz-1]);
             allbuffer = (char *) realloc ( allbuffer, sizeof (char)*(allbufsize+1));
             strcat(allbuffer,buffer);
             free(buffer);
@@ -1288,7 +1289,7 @@ mpi_broadcast_results (world_fmt * world, long loci,
         MPI_Barrier(comm_world);
         MPI_Bcast (workload, 2 * (loci) + 2, MPI_LONG, MASTER, comm_world);
         MPI_Bcast (allbuffer, allbufsize+1, MPI_CHAR, MASTER, comm_world);
-        printf("%i> Locus %li results sent\n",myID, locus);
+        //printf("%i> Locus %li results sent\n",myID, locus);
     }
     else
     { // worker node
@@ -1307,7 +1308,7 @@ mpi_broadcast_results (world_fmt * world, long loci,
             (*unpack)(allbuffer + offset, world, locus, maxreplicate,
                       world->numpop);
         }
-        printf("%i> Loci results received\n",myID);
+       // printf("%i> Loci results received\n",myID);
     }
 #else
     for (locus = 0; locus < loci; locus++)
@@ -1318,7 +1319,7 @@ mpi_broadcast_results (world_fmt * world, long loci,
                               world->numpop);
             MPI_Bcast (&bufsize, 1, MPI_LONG, MASTER, comm_world);
             MPI_Bcast (allbuffer, bufsize, MPI_CHAR, MASTER, comm_world);
-            printf("%i> Locus %li results sent\n",myID, locus);
+           // printf("%i> Locus %li results sent\n",myID, locus);
         }
         else
         {
@@ -1327,7 +1328,7 @@ mpi_broadcast_results (world_fmt * world, long loci,
             MPI_Bcast (allbuffer, bufsize, MPI_CHAR, MASTER, comm_world);
             (*unpack)(allbuffer, world, locus, maxreplicate,
                       world->numpop);
-            printf("%i> Locus %li results received\n",myID, locus);
+            //printf("%i> Locus %li results received\n",myID, locus);
         }
         memset (allbuffer, 0, sizeof (char) * bufsize);
     }
