@@ -146,6 +146,7 @@ data_fmt;
 #ifdef BAYESUPDATE
 typedef struct _bayes
 {
+	long count;
     double *delta; // change scale [how big can this be
     double *minparam;// minimal allowed parameter value
     double *maxparam; // maximal allowed parameter value
@@ -292,6 +293,7 @@ typedef struct _option
     long saveseed;
     /* mcmc options */
     boolean bayes_infer;
+	double updateratio;
 #ifdef BAYESUPDATE
 
     bayes_fmt *bayes;
@@ -612,6 +614,8 @@ typedef struct _worldoption
 
     boolean fastlike;
     boolean bayes_infer;
+	double updateratio;
+
 }
 worldoption_fmt;
 
@@ -758,8 +762,7 @@ typedef struct _world
     long accept;
     long G;
 #ifdef BAYESUPDATE
-
-    long bayesaccept;
+	long bayesaccept;
     bayes_fmt *bayes;
     FILE *bayesfile;
 #endif
