@@ -22,7 +22,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-   $Id: sighandler.c,v 1.16 2002/06/20 06:25:38 beerli Exp $                  
+   $Id: sighandler.c,v 1.17 2002/07/18 14:29:46 beerli Exp $                  
    ----------------------------------------------------- */
 //#include <stdio.h>
 #ifndef __MWERKS__
@@ -290,7 +290,7 @@ myfgets (char *buffer, long bufsize, FILE * infile)
     long count = 0;
     char ch = '\0';
     bufsize--;
-    while (!(ch == '\r' || ch == '\n') && count < bufsize)
+    while (!(ch == '\r' || ch == '\n' || ch == EOF) && count < bufsize)
     {
         ch = fgetc (infile);
         buffer[count] = ch;
