@@ -19,7 +19,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c,v 1.54 2002/06/20 06:25:38 beerli Exp $
+$Id: tools.c,v 1.55 2002/07/12 18:14:08 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "data.h"
@@ -206,24 +206,37 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 {
     if (myID == MASTER)
     {
-        openfile (&data->infile, options->infilename, "r+", appl, NULL);
-        openfile (&world->outfile, options->outfilename, "w+", appl, NULL);
-        if (options->treeprint > 0)
-            openfile (&world->treefile, options->treefilename, "w+", appl, NULL);
-        if (options->mighist)
-            openfile (&world->mighistfile, options->mighistfilename, "w+", appl,
-                      NULL);
-        if (options->writelog)
-            openfile (&options->logfile, options->logfilename, "w+", appl, NULL);
-        if (options->writesum)
-            openfile (&data->sumfile, options->sumfilename, "w+", appl, NULL);
-        if (options->aic)
-            openfile (&options->aicfile, options->aicfilename, "w+", appl, NULL);
+		if (!options->readsum)
+		{
+			openfile (&data->infile, options->infilename, "r+", appl, NULL);
+			if (options->treeprint > 0)
+				openfile (&world->treefile, options->treefilename, "w+", appl, NULL);
+			if (options->usertree)
+				openfile (&data->utreefile, options->utreefilename, "r+", appl, NULL);
+			if (options->weights)
+				openfile (&data->weightfile, options->weightfilename, "r+", appl, NULL);
+			if (options->categs > 1)
+				openfile (&data->catfile, options->catfilename, "r+", appl, NULL);
+			if (options->dist)
+				openfile (&data->distfile, options->distfilename, "r+", appl, NULL);
+			if (options->writesum)
+				openfile (&data->sumfile, options->sumfilename, "w+", appl, NULL);
+		}
+		else
+			openfile (&data->sumfile, options->sumfilename, "r+", appl, NULL);
+		
+		openfile (&world->outfile, options->outfilename, "w+", appl, NULL);
+		if (options->mighist)
+			openfile (&world->mighistfile, options->mighistfilename, "w+", appl,NULL);
+		if (options->writelog)
+			openfile (&options->logfile, options->logfilename, "w+", appl, NULL);
+		if (options->aic)
+			openfile (&options->aicfile, options->aicfilename, "w+", appl, NULL);
         if (options->plot)
         {
             switch (options->plotmethod)
             {
-            case 0:
+            case PLOTALL:
                 openfile (&world->mathfile, options->mathfilename, "w+", appl,
                           NULL);
                 break;
@@ -231,16 +244,6 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
                 break;
             }
         }
-        if (options->usertree)
-            openfile (&data->utreefile, options->utreefilename, "r+", appl, NULL);
-        if (options->readsum)
-            openfile (&data->sumfile, options->sumfilename, "r+", appl, NULL);
-        if (options->weights)
-            openfile (&data->weightfile, options->weightfilename, "r+", appl, NULL);
-        if (options->categs > 1)
-            openfile (&data->catfile, options->catfilename, "r+", appl, NULL);
-        if (options->dist)
-            openfile (&data->distfile, options->distfilename, "r+", appl, NULL);
         if (options->geo)
             openfile (&data->geofile, options->geofilename, "r+", appl, NULL);
 #ifdef UEP
@@ -262,28 +265,36 @@ exit_files (world_fmt * world, data_fmt * data, option_fmt * options)
 {
     if(myID==MASTER)
     {
-        FClose (data->infile);
-        FClose (world->outfile);
-        if (options->writelog)
+		if (!options->readsum)
+		  {
+			FClose (data->infile);
+			if (options->treeprint > 0)
+				FClose (world->treefile);
+			if(options->usertree)
+				FClose(data->utreefile);
+			if (options->weights)
+				FClose (data->weightfile);
+			if (options->categs > 1)
+				FClose (data->catfile);
+			if (options->dist)
+				FClose (data->distfile);
+		  }
+
+			if (options->writesum || options->readsum)
+				FClose (data->sumfile);
+
+			FClose (world->outfile);
+
+			if (options->writelog)
             FClose (options->logfile);
-        if (options->weights)
-            FClose (data->weightfile);
-        if (options->categs > 1)
-            FClose (data->catfile);
-        if (options->treeprint)
-            FClose (world->treefile);
         if (options->mighist)
             FClose (world->mighistfile);
-        if (options->dist)
-            FClose (data->distfile);
         if (options->geo)
             FClose (data->geofile);
         if (options->aic)
             FClose (options->aicfile);
         if (options->plot && options->plotmethod == PLOTALL)
             FClose (world->mathfile);
-        if (options->writesum || options->readsum)
-            FClose (data->sumfile);
 #ifdef UEP
 
         if (options->uep)
